@@ -5,22 +5,22 @@ from .core import (
     use_signature,
     update_subtraits,
     update_nested,
-    write_file_or_filename,
     display_traceback,
     SchemaBase,
     Undefined
 )
+from .html import spec_to_html
 from .plugin_registry import PluginRegistry
 
 
 __all__ = (
     'infer_vegalite_type',
     'sanitize_dataframe',
+    'spec_to_html',
     'parse_shorthand',
     'use_signature',
     'update_subtraits',
     'update_nested',
-    'write_file_or_filename',
     'display_traceback',
     'SchemaBase',
     'Undefined',
